@@ -127,7 +127,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     let val = guard.deref();
                     let headers = val.headers().clone();
 
-                    let maybe_callback_args: Option<CallbackArgs> = super::#pwh_name(headers, body).await.map_err(|e| {
+                    let maybe_callback_args = super::#pwh_name(headers, body).await.map_err(|e| {
                         let out: HttpError = e.into();
                         out
                     })?;
@@ -204,6 +204,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::context::ClientContextProvider;
             use checkout_core::master_context::MasterContext;
             use checkout_core::order::{Order, LookupKey};
+            use checkout_core::error::new_application_error;
             use checkout_core::checkout::handlers::{
                 create_handler,
                 add_item_handler,
